@@ -6,7 +6,9 @@ import operator
 import functools
 import itertools
 
-from . import lookups, utilities, exceptions
+from distutils.version import LooseVersion
+
+from . import lookups, exceptions
 
 
 class BaseResourceSet(object):
@@ -42,24 +44,49 @@ class BaseResourceSet(object):
 
         return self._total_count
 
-    def export(self, fmt, savepath=None, filename=None):
+    def export(self, fmt, savepath=None, filename=None, columns=None, encoding='UTF-8'):
         """
         Exports all resources from resource set to requested format if Resource supports that.
 
         :param string fmt: (required). Format to use for export, e.g. atom, csv, txt, pdf, html etc.
         :param string savepath: (optional). Path where to save the file.
         :param string filename: (optional). Name that will be used for the file.
+        :param columns: (optional). Iterable of column names, "all_gui" for GUI behaviour or "all" for all columns.
+        :param encoding: (optional). Encoding that will be used by Redmine for the result file.
+        :type columns: iterable or string
         """
         if self.manager.resource_class.query_all_export is None:
             raise exceptions.ExportNotSupported
 
-        formatter = utilities.MemorizeFormatter()
+        url = self.manager.redmine.url + self.manager.resource_class.query_all_export.format(
+                format=fmt, **self.manager.params)
 
-        url = self.manager.redmine.url + formatter.format(
-            self.manager.resource_class.query_all_export, format=fmt, **self.manager.params)
+        params = dict(self.manager.resource_class.query_all_export.formatter.unused_kwargs, encoding=encoding)
+
+        if columns is not None:
+            if columns == 'all':
+                columns = ['all', 'all_inline'] + self.manager.resource_class.extra_export_columns
+
+                if self.manager.redmine.ver is not None and LooseVersion(str(self.manager.redmine.ver)) < '3.4.0':
+                    params.update(dict.fromkeys(self.manager.resource_class.extra_export_columns, 1), columns='all')
+            elif 'all_gui' in columns:
+                if columns == 'all_gui':
+                    columns = ['all', 'all_inline']
+
+                    if self.manager.redmine.ver is not None and LooseVersion(str(self.manager.redmine.ver)) < '3.4.0':
+                        params['columns'] = 'all'
+                else:
+                    if self.manager.redmine.ver is not None and LooseVersion(str(self.manager.redmine.ver)) < '3.4.0':
+                        params.update(dict.fromkeys(columns, 1), columns='all')
+
+                    columns = list(columns) + ['all', 'all_inline']
+
+            # Redmine >= 3.4.0 happily accepts c[] array with column names
+            # for older versions the above hack with params is being used
+            params['c[]'] = columns
 
         try:
-            return self.manager.redmine.download(url, savepath, filename, params=formatter.unused_kwargs)
+            return self.manager.redmine.download(url, savepath, filename, params=params)
         except exceptions.UnknownError as e:
             if e.status_code == 406:
                 raise exceptions.ExportFormatNotSupportedError
