@@ -702,6 +702,17 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
         wiki_page = self.redmine.wiki_page.get('Foo', project_id=1)
         self.assertEqual(wiki_page.title, 'Foo')
 
+    def test_wiki_page_get_special(self):
+        """Test getting a wiki page with special char in title."""
+        self.response.json.return_value = responses['wiki_page']['get_special']
+        wiki_page = self.redmine.wiki_page.get('Foo%Bar', project_id=1)
+        self.assertEqual(
+            self.patch_requests.call_args[0][1],
+            '{0}/projects/1/wiki/Foo%25Bar.json'.format(self.url)
+        )
+        self.assertEqual(wiki_page.title, 'Foo%Bar')
+        self.assertEqual(wiki_page.url, 'http://foo.bar/projects/1/wiki/Foo%25Bar')
+
     def test_wiki_page_filter(self):
         self.response.json.return_value = responses['wiki_page']['filter']
         wiki_pages = self.redmine.wiki_page.filter(project_id=1)
@@ -714,6 +725,17 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
         wiki_page = self.redmine.wiki_page.create(project_id='foo', title='Foo')
         self.assertEqual(wiki_page.title, 'Foo')
 
+    def test_wiki_page_create_special(self):
+        """Test creating a wiki page with special char in title."""
+        self.response.status_code = 201
+        self.response.json.return_value = responses['wiki_page']['get_special']
+        wiki_page = self.redmine.wiki_page.create(project_id='foo', title='Foo%Bar')
+        self.assertEqual(
+            self.patch_requests.call_args[0][1],
+            '{0}/projects/foo/wiki/Foo%25Bar.json'.format(self.url)
+        )
+        self.assertEqual(wiki_page.title, 'Foo%Bar')
+
     def test_wiki_page_delete(self):
         self.response.json.return_value = responses['wiki_page']['get']
         wiki_page = self.redmine.wiki_page.get('Foo', project_id=1)
@@ -996,6 +1018,12 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
         self.assertEqual(user.id, 1)
         self.assertEqual(user.firstname, 'John')
 
+    def test_user_get_account(self):
+        self.response.json.return_value = responses['user']['get']
+        user = self.redmine.user.get('me')
+        self.assertEqual(user.firstname, 'John')
+        self.assertTrue(self.patch_requests.call_args[0][1].endswith('/my/account.json'))
+
     def test_user_all(self):
         self.response.json.return_value = responses['user']['all']
         users = self.redmine.user.all()
@@ -1019,6 +1047,13 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
         self.assertEqual(user.firstname, 'John')
         self.assertEqual(user.lastname, 'Smith')
 
+    def test_user_create_with_send_information(self):
+        import json
+        self.response.status_code = 201
+        self.response.json.return_value = responses['user']['get']
+        self.redmine.user.create(firstname='John', lastname='Smith', send_information=True)
+        self.assertEqual(json.loads(self.patch_requests.call_args[1]['data'])['send_information'], True)
+
     def test_user_delete(self):
         self.response.json.return_value = responses['user']['get']
         user = self.redmine.user.get(1)
@@ -1033,6 +1068,16 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
         user.firstname = 'Bar'
         self.assertIsInstance(user.save(), resources.User)
 
+    def test_user_update_account(self):
+        self.redmine.user.update('me', lastname='Foo', firstname='Bar')
+        self.assertTrue(self.patch_requests.call_args[0][1].endswith('/my/account.json'))
+
+    def test_user_update_with_send_information(self):
+        import json
+        self.response.json.return_value = responses['user']['get']
+        self.redmine.user.update(1, firstname='John', lastname='Smith', send_information=True)
+        self.assertEqual(json.loads(self.patch_requests.call_args[1]['data'])['send_information'], True)
+
     def test_user_custom_str(self):
         self.response.json.return_value = responses['user']['get']
         self.assertEqual(str(self.redmine.user.get(1)), 'John Smith')
@@ -1167,7 +1212,7 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
         self.assertEqual(self.redmine.news.resource_class.redmine_version, '1.1')
 
     def test_news_get(self):
-        self.response.json.return_value = responses['news']['all']
+        self.response.json.return_value = responses['news']['get']
         news = self.redmine.news.get(1)
         self.assertEqual(news.id, 1)
         self.assertEqual(news.title, 'Foo')
@@ -1175,22 +1220,49 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
     def test_news_all(self):
         self.response.json.return_value = responses['news']['all']
         news = self.redmine.news.all()
-        self.assertEqual(news[0].id, 1)
+        self.assertEqual(news[0].id, 2)
         self.assertEqual(news[0].title, 'Foo')
-        self.assertEqual(news[1].id, 2)
+        self.assertEqual(news[1].id, 1)
         self.assertEqual(news[1].title, 'Bar')
 
     def test_news_filter(self):
         self.response.json.return_value = responses['news']['filter']
         news = self.redmine.news.filter(project_id=1)
-        self.assertEqual(news[0].id, 1)
+        self.assertEqual(news[0].id, 2)
         self.assertEqual(news[0].title, 'Foo')
-        self.assertEqual(news[1].id, 2)
+        self.assertEqual(news[1].id, 1)
         self.assertEqual(news[1].title, 'Bar')
 
+    def test_news_create(self):
+        self.response.status_code = 201
+        self.response.json.return_value = responses['news']['get']
+        news = self.redmine.news.create(project_id=1, title='Foo')
+        self.assertEqual(news.title, 'Foo')
+
+    def test_news_create_empty_response(self):
+        self.set_patch_side_effect([
+            mock.Mock(status_code=204, history=[], content=''),
+            mock.Mock(status_code=201, history=[], **{'json.return_value': responses['news']['filter']})
+        ])
+        news = self.redmine.news.create(project_id=1, title='Foo')
+        self.assertEqual(news.title, 'Foo')
+
+    def test_news_delete(self):
+        self.response.json.return_value = responses['news']['get']
+        news = self.redmine.news.get(1)
+        self.response.content = ''
+        self.assertEqual(news.delete(), True)
+        self.assertEqual(self.redmine.news.delete(1), True)
+
+    def test_news_update(self):
+        self.response.json.return_value = responses['news']['get']
+        news = self.redmine.news.get(1)
+        news.title = 'Bar'
+        self.assertIsInstance(news.save(), resources.News)
+
     def test_news_url(self):
         self.response.json.return_value = responses['news']['filter']
-        self.assertEqual(self.redmine.news.filter(project_id=1)[0].url, '{0}/news/1'.format(self.url))
+        self.assertEqual(self.redmine.news.filter(project_id=1)[0].url, '{0}/news/2'.format(self.url))
 
     @mock.patch('redminelib.open', mock.mock_open(), create=True)
     def test_news_export(self):
@@ -1204,7 +1276,7 @@ class StandardResourcesTestCase(BaseRedmineTestCase):
 
     def test_news_repr(self):
         self.response.json.return_value = responses['news']['filter']
-        self.assertEqual(repr(self.redmine.news.filter(project_id=1)[0]), '<redminelib.resources.News #1 "Foo">')
+        self.assertEqual(repr(self.redmine.news.filter(project_id=1)[0]), '<redminelib.resources.News #2 "Foo">')
 
     def test_issue_status_version(self):
         self.assertEqual(self.redmine.issue_status.resource_class.redmine_version, '1.3')
